pub struct ClientStatisticsAggregator { /* private fields */ }Expand description
Aggregator for client statistics.
Client statistics are represented by generating an “aggregation key” for a given span, and then grouping statistics by that key. The aggregation key includes fields like service, span name, span operation, response code, and more. This is meant to group like spans together,
Implementations
Sourceimpl ClientStatisticsAggregator
impl ClientStatisticsAggregator
Sourcepub fn merge_payload(
&mut self,
payload: &StatsPayload,
) -> Result<(), GenericError>
pub fn merge_payload( &mut self, payload: &StatsPayload, ) -> Result<(), GenericError>
Merges the given payload into the aggregator.
Sourcepub fn groups(&self) -> &FastHashMap<AggregationKey, BucketedClientStatistics>
pub fn groups(&self) -> &FastHashMap<AggregationKey, BucketedClientStatistics>
Returns a reference to the aggregated statistics groups.