pub struct Span { /* private fields */ }Expand description
A simplified span representation.
Implementations
Sourceimpl Span
impl Span
Sourcepub fn get_meta_field(&self, meta_key: &str) -> Option<&str>
pub fn get_meta_field(&self, meta_key: &str) -> Option<&str>
Returns the value of the metadata entry of the given key, if it exists.
Sourcepub fn get_spans_from_agent_payload(payload: &AgentPayload) -> Vec<Self>
pub fn get_spans_from_agent_payload(payload: &AgentPayload) -> Vec<Self>
Gets all spans from the classic and indexed tracer payloads in the given AgentPayload.