pub struct Metric { /* private fields */ }Expand description
A simplified metric representation.
Implementations
Sourceimpl Metric
impl Metric
Sourcepub fn context(&self) -> &MetricContext
pub fn context(&self) -> &MetricContext
Returns the context of the metric.
Sourcepub fn values(&self) -> &[(u64, MetricValue)]
pub fn values(&self) -> &[(u64, MetricValue)]
Returns the values associated with the metric.
Sourceimpl Metric
impl Metric
Sourcepub fn try_from_series_v1(payload: &[u8]) -> Result<Vec<Self>, GenericError>
pub fn try_from_series_v1(payload: &[u8]) -> Result<Vec<Self>, GenericError>
Attempts to parse metrics from a series v1 payload.
V1 keeps a separate device JSON field rather than a device:<value> tag like the V2 protobuf encoder. To
keep the post-conversion stele::Metric representation comparable between V1 and V2 payloads, this re-injects
device:<value> into the tag list when the JSON device field is non-empty.
Errors
If the JSON can’t be deserialized, contains invalid data (for example, an unknown type), or has out-of-range
timestamps, an error is returned.
Sourcepub fn try_from_series_v2(
payload: MetricPayload,
) -> Result<Vec<Self>, GenericError>
pub fn try_from_series_v2( payload: MetricPayload, ) -> Result<Vec<Self>, GenericError>
Attempts to parse metrics from a series v2 payload.
Errors
If the metric payload contains invalid data, an error will be returned.
Sourcepub fn try_from_sketch(
payload: SketchPayload,
) -> Result<Vec<Self>, GenericError>
pub fn try_from_sketch( payload: SketchPayload, ) -> Result<Vec<Self>, GenericError>
Attempts to parse metrics from a sketch payload.
Errors
If the sketch payload contains invalid data, an error will be returned.